@@ -4,15 +4,14 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Exporter 'import';
 
 our @EXPORT    = qw/return_modifiers/;
 our @EXPORT_OK = qw/return_modifiers return_has return_with return_around return_extends return_before return_after/;
 
-use feature qw/state/;
-state $moo_modifiers = [qw/has with around extends before after/];
+our $moo_modifiers; BEGIN { $moo_modifiers = [qw/has with around extends before after/] };
 
 sub return_modifiers {
     my %modifiers = ();
@@ -55,7 +54,7 @@ MooX::ReturnModifiers - Returns Moo Modifiers as a Hash
 
 =head1 VERSION
 
-Version 0.03
+ersion 0.04
 
 =head1 SYNOPSIS
 
